@@ -12,7 +12,7 @@ from google.protobuf import timestamp_pb2
 from trexlib.utils.security_util import create_basic_authentication, verfiy_basic_authentication
 from trexlib.utils.string_util import random_string
 
-logger = logging.getLogger('util')
+logger = logging.getLogger('utils-debug')
 
 def create_task(task_url, queue_name, payload=None, in_seconds=None, http_method='get', headers=None, 
                 credential_path=None, project_id=None, location=None, service_email=None): 
